@@ -38,8 +38,8 @@ __PACKAGE__->config
                           }
               },
               openid => {
-                  ua_class => "LWPx::ParanoidAgent",
-#                  ua_class => "LWP::UserAgent",
+#                  ua_class => "LWPx::ParanoidAgent",
+                  ua_class => "LWP::UserAgent",
                   ua_args => {
                       whitelisted_hosts => [qw/ 127.0.0.1 localhost /],
                   },
